@@ -47,11 +47,10 @@ Rcpp::List blockpfGaussianOpt_impl(arma::vec data, long part, long lag)
     lIterates = y.size();
 
     //Initialise and run the sampler
-    smc::sampler<arma::vec,smc::nullParams> Sampler(lNumber, HistoryType::NONE);  
-    smc::moveset<arma::vec,smc::nullParams> Moveset(fInitialise, fMove, NULL);
+	myMove = new BSPFG_move;
+    smc::sampler<arma::vec,smc::nullParams> Sampler(lNumber, HistoryType::NONE, myMove);
 
     Sampler.SetResampleParams(ResampleType::SYSTEMATIC, 0.5);
-    Sampler.SetMoveSet(Moveset);
 
     Sampler.Initialise();
     Sampler.IterateUntil(lIterates - 1);
@@ -65,6 +64,8 @@ Rcpp::List blockpfGaussianOpt_impl(arma::vec data, long part, long lag)
     }
     
     double logNC = Sampler.GetLogNCPath();
+	
+	delete myMove;
 
     return Rcpp::List::create(Rcpp::_["weight"] = resWeights, Rcpp::_["values"] = resValues, Rcpp::_["logNC"] = logNC);
 }
@@ -77,7 +78,7 @@ namespace BSPFG {
     /// \param value The value of the particle being moved
     /// \param logweight The log weight of the particle being moved
     /// \param param Additional algorithm parameters
-    void fInitialise(arma::vec & value, double & logweight, smc::nullParams & param)
+    void BSPFG_move::pfInitialise(arma::vec & value, double & logweight, smc::nullParams & param)
     {
         value = arma::zeros<arma::vec>(lIterates);
         value(0) = R::rnorm(0.5 * y(0),1.0/sqrt(2.0));
@@ -90,7 +91,7 @@ namespace BSPFG {
     ///\param value The value of the particle being moved
     ///\param logweight The log weight of the particle being moved
     ///\param param Additional algorithm parameters
-    void fMove(long lTime, arma::vec & value, double & logweight, smc::nullParams & param)
+    void BSPFG_move::pfMove(long lTime, arma::vec & value, double & logweight, smc::nullParams & param)
     {
         if(lTime == 1) {
             value(lTime) = (value(lTime-1) + y(lTime))/2.0 + R::rnorm(0.0,1.0/sqrt(2.0));
